@@ -4,7 +4,7 @@ couchbasekit.document
 ~~~~~~~~~~~~~~~~~~~~~
 
 :website: http://github.com/kirpit/couchbasekit
-:copyright: Copyright 2012, Roy Enjoy <kirpit *at* gmail.com>, see AUTHORS.txt.
+:copyright: Copyright 2013, Roy Enjoy <kirpit *at* gmail.com>, see AUTHORS.txt.
 :license: MIT, see LICENSE.txt for details.
 """
 import datetime
@@ -36,10 +36,10 @@ class Document(SchemaDocument):
     DoesNotExist = DoesNotExist
     __bucket_name__ = None
     __view_name__ = None
-    _bucket = None
     _hashed_key = None
     _view_design_doc = None
     _view_cache = None
+    full_set = False
     cas_value = None
 
     def __init__(self, key_or_map=None, get_lock=False, **kwargs):
@@ -63,6 +63,9 @@ class Document(SchemaDocument):
             return True
         return False
 
+    def __ne__(self, other):
+        return not self.__eq__(other)
+
     def __getattr__(self, item):
         if item in self:
             return self[item]
@@ -107,20 +110,18 @@ class Document(SchemaDocument):
         :returns: See: :class:`couchbase.client.Bucket`.
         :rtype: :class:`couchbase.client.Bucket`
         """
-        if self._bucket is None:
-            self._bucket = Connection.bucket(self.__bucket_name__)
-        return self._bucket
+        return Connection.bucket(self.__bucket_name__)
 
-    def view(self, view=None):
-        """Returns the couchbase view(s) if :attr:`__view_name__` was provided
-            within model class.
+    def view(self, view_name=None):
+        """Returns a couchbase view (or design document view with no view_name
+        provided) if :func:`couchbasekit.viewsync.register_view` decorator was
+        applied to model class.
 
-        :param view: If provided returns the asked couchbase view object or
-            :attr:`__view_name__` design document.
-        :type view: str
+        :param view_name: If provided returns the asked couchbase view object
+            or design document otherwise.
+        :type view_name: str
         :returns: couchbase design document, couchbase view or None
-        :rtype: :class:`couchbase.client.DesignDoc` or
-            :class:`couchbase.client.View` or None
+        :rtype: :class:`couchbase.client.View` or :class:`couchbase.client.DesignDoc` or None
         """
         if self.__view_name__ is None:
             return None
@@ -128,12 +129,27 @@ class Document(SchemaDocument):
         if self._view_design_doc is None:
             self._view_design_doc = self.bucket['_design/%s' % self.__view_name__]
         # return the design doc
-        if view is None:
+        if view_name is None:
             return self._view_design_doc
         # cache the views
-        if self._view_cache is None:
-            self._view_cache = self._view_design_doc.views()
-        return next(iter([v for v in self._view_cache if v.name==view]), None)
+        if not self._view_cache:
+            # patch is not necessary
+            if not self._view_design_doc.name.startswith('dev_') or not self.full_set:
+                self._view_cache = self._view_design_doc.views()
+            # patch'em all
+            else:
+                def results(instance, params={}):
+                    if 'full_set' not in params:
+                        params['full_set'] = True
+                    return instance._results(params)
+                self._view_cache = list()
+                from couchbase.client import View
+                for view in self._view_design_doc.views():
+                    func_type = type(view.results)
+                    view._results = view.results
+                    view.results = func_type(results, view, View)
+                    self._view_cache.append(view)
+        return next(iter([v for v in self._view_cache if v.name==view_name]), None)
 
     def _fetch_data(self, get_lock=False):
         try:
@@ -196,12 +212,12 @@ class Document(SchemaDocument):
             data[key] = self._encode_item(value)
         return data
 
-    def save(self, expiry=0):
+    def save(self, expiration=0):
         """Saves the current instance after validating it.
 
-        :param expiry: Expiration in seconds for the document to be removed by
+        :param expiration: Expiration in seconds for the document to be removed by
             couchbase server, defaults to 0 - will never expire.
-        :type expiry: int
+        :type expiration: int
         :returns: couchbase document CAS value
         :rtype: int
         :raises: :exc:`couchbasekit.errors.StructureError`,
@@ -221,7 +237,7 @@ class Document(SchemaDocument):
         if self.doc_id is None:
             self._hashed_key = hashlib.sha1(json_data).hexdigest()[0:12]
         # finally
-        self.cas_value = self.bucket.set(self.doc_id, expiry, 0, json_data)[1]
+        self.cas_value = self.bucket.set(self.doc_id, expiration, 0, json_data)[1]
         return self.cas_value
 
     def delete(self):
@@ -235,3 +251,18 @@ class Document(SchemaDocument):
         if not self.cas_value or not self.doc_id:
             raise self.DoesNotExist(self)
         return self.bucket.delete(self.doc_id, self.cas_value)
+
+    def touch(self, expiration):
+        """Updates the current document's expiration value.
+
+        :param expiration: Expiration in seconds for the document to be removed by
+            couchbase server, defaults to 0 - will never expire.
+        :type expiration: int
+        :returns: Response from CouchbaseClient.
+        :rtype: unicode
+        :raises: :exc:`couchbasekit.errors.DoesNotExist` or
+            :exc:`couchbase.exception.MemcachedError`
+        """
+        if not self.cas_value or not self.doc_id:
+            raise self.DoesNotExist(self)
+        return self.bucket.touch(self.doc_id, expiration)
\ No newline at end of file
